SystemOrganization addCategory: #'GT-Tests-Inspector'!

GLMMorphicTest subclass: #GTUnprintableObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Tests-Inspector'!

!GTUnprintableObjectTest commentStamp: '<historical>' prior: 0!
GTUnprintableObjectTest is a test that checks that print string does not trigger an error in the inspector.!

!GTUnprintableObjectTest methodsFor: 'printing' stamp: 'TudorGirba 5/25/2012 17:13'!
printString
	"Simulate an error in printString"
	1/0! !

!GTUnprintableObjectTest methodsFor: 'tests' stamp: 'TudorGirba 5/25/2012 17:12'!
testInspectDoesNotCrash
	window := GTInspector openOn: self class new ! !

TestCase subclass: #GTInspectorExamplesTest
	instanceVariableNames: 'windows'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Tests-Inspector'!

!GTInspectorExamplesTest methodsFor: 'tests' stamp: 'TudorGirba 8/15/2015 14:32'!
checkAllPresentationsOf: exampleToTest
	| browser window pragmas |
	pragmas := Pragma allNamed: #gtInspectorPresentationOrder: from: exampleToTest class to: Object.
	^ pragmas
		do: [ :eachPragma | 
			browser := GLMWrapper new.
			[browser
				show: [ :composite | 
					(eachPragma selector findTokens: $:) size = 1
						ifTrue: [ exampleToTest perform: eachPragma selector with: composite ].
					(eachPragma selector findTokens: $:) size = 2
						ifTrue: [ exampleToTest perform: eachPragma selector with: composite with: browser ] ].
			window := browser openOn: exampleToTest] 
				on: Error 
				do: [ self fail: (eachPragma method gtDisplayString, ' for ', exampleToTest gtDisplayString)  ].
			window ifNotNil: [ window delete ] ]! !

!GTInspectorExamplesTest methodsFor: 'running' stamp: 'TudorGirba 1/29/2014 07:44'!
setUp 
	windows := OrderedCollection new! !

!GTInspectorExamplesTest methodsFor: 'running' stamp: 'AndreiChis 3/3/2015 11:04'!
tearDown 
	windows do: [ :each | each delete ].
	windows := nil! !

!GTInspectorExamplesTest methodsFor: 'tests' stamp: 'StefanReichhart 9/7/2015 22:16'!
testAllExamples
	<todo: 'fix the #gtExamples for the finder'>
	(Object withAllSubclasses difference: GTExampleFinder withAllSubclasses) 
		do: [ :eachClass | 
			eachClass gtExamples do: [ :exampleToTest | 
				self checkAllPresentationsOf: exampleToTest ] ]
		displayingProgress: 'Testing GTInspector examples (#testAllExamples)'! !

!GTInspectorExamplesTest methodsFor: 'tests' stamp: 'StefanReichhart 3/27/2015 19:46'!
testGlobals
	{ Smalltalk . RBMessageNode . Trait . TClass . TBehavior . GTInspector . Object . Class . CompiledMethod } 
		do: [ :each | self checkAllPresentationsOf: each ]
		displayingProgress: 'Testing GTInspector globals (#testGlobals)'! !

TestCase subclass: #GTInspectorVariableValuePairsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Tests-Inspector'!

!GTInspectorVariableValuePairsTest methodsFor: 'object' stamp: 'TommasoDalSasso 1/30/2015 17:33'!
testArrayPairs41
	| pairs |
	
	pairs := (1 to: 41) asArray gtInspectorVariableValuePairs.
	self assert: pairs size = 41.
	(pairs collect: #key) allSatisfy: [ :e | (pairs at: e) = e ].
	
	self assert: ((pairs collect: #key) = (1 to: 41) asOrderedCollection).! !

!GTInspectorVariableValuePairsTest methodsFor: 'object' stamp: 'TommasoDalSasso 1/30/2015 17:33'!
testArrayPairs42
	| pairs |
	
	pairs := (1 to: 42) asArray gtInspectorVariableValuePairs.
	self assert: pairs size = 42.
	(pairs collect: #key) allSatisfy: [ :e | (pairs at: e) = e ].
	
	self assert: ((pairs collect: #key) = (1 to: 42) asOrderedCollection).! !

!GTInspectorVariableValuePairsTest methodsFor: 'object' stamp: 'TommasoDalSasso 1/30/2015 17:34'!
testArrayPairs43
	| pairs |
	
	pairs := (1 to: 43) asArray gtInspectorVariableValuePairs.
	self assert: pairs size = 42.
	(pairs collect: #key) allSatisfy: [ :e | (pairs at: e) = e ].
	
	self assert: ((pairs collect: #key) = ((1 to: 21) asOrderedCollection addAll: (23 to: 43) asOrderedCollection; yourself)).! !

!GTInspectorVariableValuePairsTest methodsFor: 'object' stamp: 'TommasoDalSasso 1/30/2015 17:33'!
testArrayPairsLong
	| pairs |
	
	pairs := (1 to: 100) asArray gtInspectorVariableValuePairs.
	self assert: pairs size = 42.
	(pairs collect: #key) allSatisfy: [ :e | (pairs at: e) = e ].
	
	self assert: ((pairs collect: #key) = ((1 to: 21) asOrderedCollection addAll: (80 to: 100) asOrderedCollection; yourself)).! !

!GTInspectorVariableValuePairsTest methodsFor: 'object' stamp: 'TommasoDalSasso 1/30/2015 17:21'!
testArrayPairsSmall
	| pairs |
	
	pairs := (1 to: 10) asArray gtInspectorVariableValuePairs.
	self assert: pairs size = 10.
	(pairs collect: #key) allSatisfy: [ :e | (pairs at: e) = e ].! !

!GTInspectorVariableValuePairsTest methodsFor: 'context' stamp: 'TommasoDalSasso 1/30/2015 18:03'!
testContextPairs
	| pairs x tempVariables indexVariables instVariables |
	
	x:=42.
	pairs := [:y| y+1+x ] asContext gtInspectorVariableValuePairs withIndexCollect: [ :e :i | i -> e].	
	
	tempVariables := pairs select: [ :e | e value key asString beginsWith: '[' ].
	indexVariables := pairs select: [ :e | e value key isInteger ].
	instVariables := pairs select: [ :e | e value key isSymbol ].
	
	self assert: (tempVariables sort last key) < (indexVariables sort first key).
	self assert: (indexVariables sort last key) < (instVariables sort first key).! !

!GTInspectorVariableValuePairsTest methodsFor: 'float' stamp: 'TommasoDalSasso 1/30/2015 17:39'!
testFloatPairs
	| pairs |
	
	pairs := 4.2 gtInspectorVariableValuePairs.
	self assert: pairs size = 2.
	
	self assert: (pairs first = ('1' -> 1074842828)).
	self assert: (pairs second = ('2' -> 3435973837)).! !
